---
title: "Dotawo 7: Comparative Northern East Sudanic Linguistics"
author: "Vincent W.J. van Gerven Oei"
has_articles: ["rilly.md", "jakobi.md", "norton.md", "starostin.md", "blench.md"]
---

# Preface by the Editor

## A New Platform

Since its inception, the [Union for Nubian Studies](http://unionfornubianstudies.org/) has been committed to opening up Nubiological research to a wider audience and broadening access to source materials. *Dotawo: A Journal of Nubian Studies* was launched in 2014 as an open-access journal, with free access for both authors and readers. It has been hosted by [DigitalCommons@Fairfield](https://digitalcommons.fairfield.edu/djns/) and since 2019 by University of California's [eScholarship](https://escholarship.org/uc/dotawo) platform.

Although both digital platforms allowed *Dotawo* to grow, expanding its reach by means of the creation of persistent digital identifiers and membership of the [Directory of Open Access Journals](https://doaj.org/toc/2373-2571), the content of *Dotawo* itself remained tailored toward human readers because it was only available in [pdf]({sc}) or printed form, and toward privileged readers with access to institutional libraries because the references it included themselves were often difficult to access for members of the general public, even though most if not all of this research was produced with the aid of public funds. This state of affairs presented a challenge in terms of discoverability of the journal, long-term preservation, and the openness of the scholarship presented.

With its graduation to the [Sandpoints](https://git.sandpoints.org/) platform starting with the present issue, *Dotawo* is entering a new phase. The entire journal will now be "born digital," created in [Gitea](https://gitea.io/en-us/) with a website generated by [Hugo](https://gohugo.io/). The journal is typeset in [Gentium](https://software.sil.org/gentium/), which is released under an [SIL Open Font License](http://scripts.sil.org/ofl). The [pdf]({sc}) output is generated by [PagedJS](https://www.pagedjs.org/), and will continue to be hosted on eScholarship, while the printed book will remain available through scholar-led open access press [punctum books](https://punctumbooks.com/imprints/dotawo/). All of the software used in the creation of *Dotawo* will thus be open source.

Second, to improve the long-term preservation of and access to the scholarship contained and referenced in *Dotawo*, all sources mentioned in contributions to the journal will henceforth be linked, as much as possible, to records deposited in a public library using the open infrastructure of [Memory of the World](https://www.memoryoftheworld.org/).[^10] This will allow for easy storage and dissemination of both the research and research context presented in *Dotawo* to those scholars of Nubian Studies – and there are many – who are not institutionally privileged or live in the Global South. The plundering and destruction of the University of Khartoum by forces allied with the former dictator during the 2019 Sudanese Revolution[^8] should impress upon us the precarity of the research environment in which many Nubiologists operate and thus the necessity and moral obligation of creating open and resistant scholarly infrastructures.

In a recent, bleak assessment of the goals set by the [Budapest Open Access Initiative Declaration](https://www.budapestopenaccessinitiative.org/read) in 2002 and the open access movement more broadly, journalist Richard Poynder states that "it now seems unlikely that the *affordability* and *equity* problems will be resolved, which will impact disproportionately negatively on those in the Global South”:[^5]

>OA advocates failed to anticipate – and then for too long ignored – how their advocacy was allowing legacy publishers to co-opt open access, and in ways that work as much against the goals of [boai]({sc}) as for them. And they have often downplayed the negative consequences that OA policies and initiatives developed in the Global North will have for those in the Global South.[^6]

Furthermore, it appears that the turn toward open access in the scholarly communications landscape is increasingly facilitating the agendas of for-profit data analytics companies. Perhaps realizing that "they've found something that is even more profitable than selling back to us academics the content that we have produced,”[^9] they venture ever further upstream from the moment of publication, with every intent to colonize and canalize the entire flow of research.[^4] This poses a severe threat to the independence of scholarly inquiry.[^7]

In the light of these troubling developments, the expansion from *Dotawo* as a "diamond" open access journal to a broader acknowledgment of the importance of *common access* to scholarship represents a strong reaffirmation of the call that the late Aaron Swartz succinctly formulated in his "Guerilla Open Access Manifesto":

>Those with access to these resources — students, librarians, scientists — you have been given a privilege. You get to feed at this banquet of knowledge while the rest of the world is locked out. But you need not — indeed, morally, you cannot — keep this privilege for yourselves. You have a duty to share it with the world.[^3]  

Swartz's is a call to action that transcends the limitations of the open access movement as construed by the [boai]({sc}) Declaration by simply affirming: "knowledge is a common good." It goes beyond open access, because it specifically targets materials that linger on a paper or silicon substrate in academic libraries and digital repositories without being accessible for "fair use." The deposition of the references from *Dotawo* contributions in a public library is a limited attempt to offer a remedy, heeding the "Code of Best Practices in Fair Use" of the [Association of Research Libraries](https://www.arl.org/resources/code-of-best-practices-in-fair-use-designing-the-public-domain/), which approvingly cites the late Supreme Court Justice Brandeis that “the noblest of human productions — knowledge, truths ascertained, conceptions, and ideas — become, after voluntary communication to others, free as the air to common use.”[^1] This approach also dovetails the interpretation of "folk law" recently propounded by [Ubuweb](https://ubu.com/) founder Kenneth Goldsmith.[^2]

We strongly believe that it is in the interest of Nubian Studies and its stakeholders, especially scholars in adjunct or para-academic positions without access to institutional repositories, and the Nubian people who are actively denied knowledge of their own culture, to enable the *widest possible* dissemination of scholarship. In this enterprise, striving for common access and and relying on open source software are just the first step.

[^1]: *Int’l News Serv. v. Associated Press,* 248 U.S. 215, 250 (1918) (Brandeis, J., dissenting), cited in Anon., "Designing the Public Domain," p. 1494.
[^2]: Goldsmith, *Duchamp Is My Lawyer.*
[^3]: Swartz, "Guerilla Open Access Manifesto."
[^4]: See, e.g., Moore, "The Datafication in Transformative Agreements for Open Access Publishing."
[^5]: Poynder, "Open access: 'Information wants to be free'?" p. 2.
[^6]: Ibid., p. 22.
[^7]: The reduction in agency of academics as a result of the implementation of open access schemes has been widely recognized. As Christopher Kelty put it succinctly: "OA has come to exist and scholarship is more available and more widely distributed than ever before. But, scholars now have less control, and have taken less responsibility for the means of production of scientific research, its circulation, and perhaps even the content of that science" ("Recursive Publics and Open Access," p. 7). These problems are exacerbated in the Global South, as the financial models for OA funding developed in the Global North threaten local public infrastructures managed by academics (Aguado-López & Becerril-Garcia, "The Commercial Model of Academic Publishing Underscoring Plan S Weakens the Existing Open Access Ecosystem in Latin America").
[^8]: "Report: Large Parts of University of Khartoum Destroyed on June 3."
[^9]: Bodó, "Own Nothing," p. 23.
[^10]: A public library is defined as follows: "[A] public library is: free access to books for every member of society; library catalog; librarian" (Mars, Zarroug & Medak, "Public Library," p. 85).

## This Issue

The seventh issue of *Dotawo* is dedicated to Comparative Northern East Sudanic linguistics, offering new insights in the historical connections between the Nubian languages and other members of the NES family such as Nyimang, Tama, Nara, and Meroitic. A special focus is placed on comparative morphology.

[discuss individual contributions]


# Bibliography

Aguado-López, Eduardo & Arianna Becerril-Garcia, "The Commercial Model of Academic Publishing Underscoring Plan S Weakens the Existing Open Access Ecosystem in Latin America." *LSE Impact Blog,* May 20, 2020. https://blogs.lse.ac.uk/impactofsocialsciences/2020/05/20/the-commercial-model-of-academic-publishing-underscoring-plan-s-weakens-the-existing-open-access-ecosystem-in-latin-america/.

Anon. "Designing the Public Domain." *Harvard Law Review* 122, no. 5 (2009): pp. 1489–1510.

Bodó, Balázs. "Own Nothing." In *Guerrilla Open Access,* ed. Memory of the World. Coventry: Post Office Press, Rope Press, and Memory of the World, 2018: pp. 16-24.

Goldsmith, Kenneth. *Duchamp Is My Lawyer: The Polemics, Pragmatics, and Poetics of Ubuweb.* New York: Columbia University Press, 2020.

Kelty, Christopher. "Recursive Publics and Open Access." In *Guerrilla Open Access,* ed. Memory of the World. Coventry: Post Office Press, Rope Press, and Memory of the World, 2018: pp. 6–15.

Mars, Marcell, Manar Zarroug, and Tomislav Medak. In "Public Library," edited by Marcell Mars, Tomislav Medak, and WHW. Zagreb: WHW/Multimedijalni Institut, 2015: pp. 75–85.

Moore, Samuel. "The Datafication in Transformative Agreements for Open Access Publishing." July 3, 2020. https://www.samuelmoore.org/2020/07/03/the-datafication-in-transformative-agreements-for-open-access-publishing/

"Report: Large Parts of University of Khartoum Destroyed on June 3." *Dabanga,* August 7, 2019. https://www.dabangasudan.org/en/all-news/article/report-large-parts-of-university-of-khartoum-destroyed-on-june-3.

Swartz, Aaron. "Guerrilla Open Access Manifesto." July 2008. https://archive.org/details/GuerillaOpenAccessManifesto/page/n1/mode/2up.
